import time
import machine
from pimoroni import Button
from picographics import PicoGraphics, DISPLAY_INKY_PACK
import enviro

class Display:
    
    def __init__(self):
        # Przypisanie przycisków z wyświetlacza
        self.button_a = Button(12)
        self.button_b = Button(13)
        self.button_c = Button(14)

        # Ustawienia wyświetlacza
        self.display = PicoGraphics(DISPLAY_INKY_PACK)
        self.WIDTH, self.HEIGHT = self.display.get_bounds()
        self.display.set_update_speed(2)
        self.display.set_font("bitmap8")

    # Funckja czyszcząca ekran
    def clear(self):
        self.display.set_pen(15)
        self.display.clear()
        
    # Funckja wyświetlająca na wyświetlaczu podaną:
    #	temperaturę
    #	ciśnienie
    #	natężenie światła
    #	prędkość wiatru
    #	kierunek wiatru
    #	deszcz
    #	wilgotność
    #	datę ostatniego pomiaru
    def show_measurements(self, temperature, pressure, luminance, wind_speed, wind_direction, rain_data, rain, humidity, rain_mm, rain_mms):
        self.clear()
        self.display.set_pen(0)
        self.display.text(f"T: {temperature} °C", 0, 0, 240, 2)
        self.display.text(f"P: {pressure} hPa" + f"    HR: {humidity} %", 0 ,20, 290, 2)
        self.display.text(f"ALS: {luminance} Lux", 0, 38, 240, 2) #cd/m²
        self.display.text("Wind speed: "+ "{:.2f}".format(wind_speed) + " m/s", 0, 56, 290, 2)
        self.display.text(f"Wind direction: {wind_direction}", 0, 74, 290, 2)
        #self.display.text(f"HR: {humidity} %", 0, 80, 240, 2)
        #self.display.text(f"Deszcz: {rain} " + "{:.2f}".format(rain_mm) + "mm " + "{:.2f}".format(rain_mms) + " mm/s", 0, 100, 290, 2)
        self.display.text(f"Rain sensor: {rain} " + "  " + str(rain_data) + " %", 0, 92, 290, 2)
        #self.display.text("Rain Gauge: {:.2f}".format(rain_mm) + " mm " + "{:.2f}".format(rain_mms) + " mm/s", 0, 92, 290, 2)
        self.display.text("Rain gauge: {:.2f}".format(rain_mm) + " mm " + "{:.2f}".format(rain_mms) + " mm/s", 0, 110, 290, 2)
        
        self.display.text("Data ostatniego pomiaru", 185, 0, 240, 1)
        self.display.text(f"{enviro.helpers.datetime_string()}", 210, 10,240,1) 
        
        self.display.update()
        
    # Funkcja wyświetlająca informację o dokonywaniu nowego pomiaru
    def new_measurements(self):
        self.display.set_pen(0)
        self.display.rectangle(48,38,200,60)
        self.display.set_pen(15)
        self.display.text("Nowy pomiar...", 78, 58, 240, 2)
        self.display.update()

