# Dołaczanie czujnika deszczu do Enviro Weather
# Na podstawie projektu 
#  "Pomiar parametrów otoczenia w tym prędkość i kierunek wiatru, opady deszczu i wilgotność powietrza"
#  autorzy: Weronika Jamróz, Julia Dollani, Kamil Szwagierczak, Mikołaj Pliś
# ---------------------------------------------------------
 
from time import sleep
import enviro
import os
import rain_sensor
import wind_sensor_helper as ws
from ink_display import Display
import machine
from machine import Pin, I2C
import wind_sensor_helper

display = Display()

# ---------------------------------------------------------
# Inicjalizacja i sprawdzanie polaczen
# BME280 0x77[119] 3,4MHz
# PCF85063A 0x51[81] 400kHz
# LTR-559ALS-01 0x23[35] 400kHz
# AS7341  0x39[57] 400kHz
# TCS34725 0x29[41] 400kHz
# ADS1115 0x48[72] 3,4MHz
def check_connections():
    i2c1 = I2C(0, scl=Pin(5), sda=Pin(4), freq=100000) # GP4, GP5
    i2c_dev_list = i2c1.scan()
    if len(i2c_dev_list) == 0:
        print("No I2C devices found, terminating")
        sys.exit(1)
    print("LTR-559ALS-01 0x23, PCF85063A 0x51, BME280 0x77, ADS1115 0x48/0x49")
    print("Detected devices at I2C1-addresses:")
    print(["0x{:02X}".format(x) for x in i2c_dev_list])
    print("Decimal address: ",i2c_dev_list)
    
    # Sprawdzanie ADS1115  0x48[72]
    if not 72 in i2c_dev_list:
        print("Failed to contact ADS1115")
        ads_flag = False
    else:
        ads1115_flag = True

    return [ads1115_flag]

# ---------------------------------------------------------
# Check I2C devices
[ads1115_flag] = check_connections()

try:
  # Wyświetl informację na ekranie o nowym pomiarze
  display.new_measurements()
  sleep(1)
  
  # initialise enviro
  print("enviro.startup()")
  enviro.startup()

  # Warunki na ustawienie zegara
  if not enviro.is_clock_set():
   enviro.logging.info("> clock not set, synchronise from ntp server")
   if not enviro.sync_clock_from_ntp():
      # Jeśli nie zsynchronizowano zegara zatrzymaj Enviro
     enviro.halt("! failed to synchronise clock")
  
  # Pobierz pomiary z czujników z Enviro
  """
    "temperature": round(bme280_data[0], 2),
    "humidity": round(bme280_data[2], 2),
    "pressure": round(bme280_data[1] / 100.0, 2),
    "luminance": round(ltr_data[BreakoutLTR559.LUX], 2),
    "wind_speed": wind_speed(),
    "rain": rain,
    "rain_per_second": rain_per_second,
    "wind_direction": wind_direction()
  """
  enviro.logging.debug(f"> taking new reading")
  reading = enviro.get_sensor_readings()
  
  # Pobierz dane z czujnika deszczu
  rain_data = rain_sensor.rain_readings()
  rain_string = rain_sensor.convert_rain_to_scale(rain_data)
  if rain_data <1:	# Poprawka na skalowanie
      rain_data = 0.0
      
  # Przekonwertuj stopnie kierunku wiatru na kierunek jako string
  reading["wind_direction"] = ws.get_wind_direction()
  print("Wind direction: ", reading["wind_direction"])
  
  # Wyświetl pomiary na wyświetlaczu
  display.show_measurements(reading["temperature"], reading["pressure"], reading["luminance"], reading["wind_speed"], reading["wind_direction"], rain_data, rain_string, reading["humidity"], reading["rain"], reading["rain_per_second"])
    
  # Uśpij Enviro do czasu następnego pomiaru
  enviro.sleep() 

# Obsługa błedu Enviro
except Exception as exc:
  print("Exception")
  enviro.exception(exc)
