# RC-SPC1K  Capacitive Rain Sensor
#  https://www.radiocontrolli.com/capacitive-rain-sensor

import time
from machine import Pin, PWM

# Pin na odczyt danych z czujnika
rain_sensor_pin = Pin(15, Pin.IN, Pin.PULL_DOWN)

# Funkcja zwracjąca informację o odczytanej pojemoności w skali 0.00 - 100.00
def rain_readings():

  last_value = rain_sensor_pin.value()
  start = time.ticks_ms()
  #print("start ", start)
  first = None
  last = None
  ticks = 0
  
  while ticks < 10 and time.ticks_diff(time.ticks_ms(), start) <= 1000: #1sec
    # wykrywanie zbocza
    value = rain_sensor_pin.value()
    if last_value != value:
      if first == None:
        first = time.ticks_ms()
      last = time.ticks_ms()
      ticks += 1
      last_value = value

    #print("tics ", ticks, "first ", first, "last ", last, " dif:", time.ticks_diff(last, first), ' value', value)

    if not first or ticks == 1 or not last:
      result = 0.0
      continue

    average = time.ticks_diff(last, first) / (ticks -1)
    #print("average ", average)
    min_ms = 12.1	# 40,71Hz odczyt dla suchego czujnika
    max_ms = 49.9	# 10,075Hz odczyt dla mokrego
    average = max(min_ms, min(max_ms, average)) # clamp range
    #print("Average:", average)
    scaled = ((average - min_ms) / (max_ms - min_ms)) * 100
    result = round(scaled, 2)
    #print("average ", average, "  scaled ", scaled, "   result ", result)
  
  return result


# Funkcja konwertująca skalę 0.00 - 100.00 na string o natężeniu deszczu
# Water 
# 0%	100pF
# 25%	180pF
# 40%	280pF
# 50%	390pF
# 100%	>550pF
def convert_rain_to_scale(data):

    #data = rain_readings()
    print("Rain data:", data,'%' )
    if data > 75:
        return "Heavy rain"
    elif data > 50:
        return "Rain fall"
    elif data > 25:
        return "Light rain"
    elif data > 1:
        return "Shower" # drizzle
    else:
        return "No rain"
